@@ -51,7 +51,7 @@
 #include "dialogs/comp-editor.h"
 #include "dialogs/copy-source-dialog.h"
 #include "dialogs/event-editor.h"
-#include "widgets/misc/e-info-label.h"
+#include "misc/e-info-label.h"
 #include "e-util/e-error.h"
 #include "e-util/e-icon-factory.h"
 #include "e-cal-menu.h"
@@ -764,9 +764,20 @@ impl_handleURI (PortableServer_Servant servant, const char *uri, CORBA_Environme
 {
 	CalendarComponent *calendar_component = CALENDAR_COMPONENT (bonobo_object_from_servant (servant));
 	CalendarComponentPrivate *priv;
+	GList *l;
+	CalendarComponentView *view = NULL;
+	char *src_uid = NULL;
+	char *uid = NULL;
+	char *rid = NULL;
 
 	priv = calendar_component->priv;
+			
+	l = g_list_last (priv->views);
+	if (!l)
+		return;
 
+	view = l->data;
+		
 	if (!strncmp (uri, "calendar:", 9)) {
 		EUri *euri = e_uri_new (uri);
 		const char *p;
@@ -795,8 +806,14 @@ impl_handleURI (PortableServer_Servant servant, const char *uri, CORBA_Environme
 					start = time_from_isodate (content);
 				} else if (!g_ascii_strcasecmp (header, "enddate")) {
 					end = time_from_isodate (content);
+				} else if (!g_ascii_strcasecmp (header, "source-uid")) {
+					src_uid = g_strdup (content);
+				} else if (!g_ascii_strcasecmp (header, "comp-uid")) {
+					uid = g_strdup (content);
+				} else if (!g_ascii_strcasecmp (header, "comp-rid")) {
+					rid = g_strdup (content);
 				}
-			
+
 				g_free (content);
 
 				p += clen;
@@ -808,20 +825,18 @@ impl_handleURI (PortableServer_Servant servant, const char *uri, CORBA_Environme
 			}
 
 			if (start != -1) {
-				GList *l;
 			
 				if (end == -1)
 					end = start;
-			
-				l = g_list_last (priv->views);
-				if (l) {
-					CalendarComponentView *view = l->data;
-				
 					gnome_calendar_set_selected_time_range (view->calendar, start, end);
-				}
 			}
+			if (src_uid && uid)
+				gnome_calendar_edit_appointment (view->calendar, src_uid, uid, rid);
+			
+			g_free (src_uid);
+			g_free (uid);
+			g_free (rid);
 		}
-
 		e_uri_free (euri);
 	}
 }
@@ -1196,7 +1211,7 @@ create_new_event (CalendarComponent *calendar_component, CalendarComponentView *
 		EventEditor *editor;
 		CompEditorFlags flags;
 
-		flags |= COMP_EDITOR_MEETING;
+		flags |= COMP_EDITOR_MEETING | COMP_EDITOR_NEW_ITEM;
 		comp = cal_comp_event_new_with_current_time (ecal, is_allday);
 		editor = event_editor_new (ecal, flags);
 		e_cal_component_commit_sequence (comp);
