@@ -109,8 +109,8 @@ eccp_commit (EConfig *ec, GSList *items, void *data)
 		e_source_update_from_xml_node (sdialog->original_source, xml->children, NULL);
 		xmlFreeNode (xml);
 
-		e_source_get_color (sdialog->source, &color);
-		e_source_set_color (sdialog->original_source, color);
+		if (e_source_get_color (sdialog->source, &color))
+			e_source_set_color (sdialog->original_source, color);
 	} else {
 		e_source_group_add_source (sdialog->source_group, sdialog->source, -1);
 		e_source_list_sync (sdialog->source_list, NULL);
@@ -412,8 +412,8 @@ calendar_setup_edit_calendar (struct _GtkWindow *parent, ESource *source, ESourc
 		sdialog->source = e_source_new_from_standalone_xml (xml);
 		g_free (xml);
 
-		e_source_get_color (source, &color);
-		e_source_set_color (sdialog->source, color);
+		if (e_source_get_color (source, &color))
+			e_source_set_color (sdialog->source, color);
 	} else {
 		GConfClient *gconf;
 		GSList *l;
@@ -442,6 +442,7 @@ calendar_setup_edit_calendar (struct _GtkWindow *parent, ESource *source, ESourc
 	e_config_add_page_check ((EConfig *) ec, NULL, eccp_check_complete, sdialog);
 
 	target = e_cal_config_target_new_source (ec, sdialog->source);
+	target->source_type = E_CAL_SOURCE_TYPE_EVENT;
 	e_config_set_target ((EConfig *) ec, (EConfigTarget *) target);
 
 	if (source)
@@ -510,6 +511,7 @@ calendar_setup_edit_task_list (struct _GtkWindow *parent, ESource *source)
 	e_config_add_page_check ((EConfig *) ec, NULL, eccp_check_complete, sdialog);
 
 	target = e_cal_config_target_new_source (ec, sdialog->source);
+	target->source_type = E_CAL_SOURCE_TYPE_TODO;
 	e_config_set_target ((EConfig *) ec, (EConfigTarget *) target);
 
 	sdialog->window = e_config_create_window ((EConfig *)ec, NULL, _("Task List Properties"));
