@@ -34,14 +34,14 @@
 #include <sys/stat.h>
 #include <unistd.h>
 #include <gnome.h>
-#include <gal/widgets/e-gui-utils.h>
-#include <gal/e-table/e-cell-checkbox.h>
-#include <gal/e-table/e-cell-toggle.h>
-#include <gal/e-table/e-cell-text.h>
-#include <gal/e-table/e-cell-combo.h>
+#include <misc/e-gui-utils.h>
+#include <table/e-cell-checkbox.h>
+#include <table/e-cell-toggle.h>
+#include <table/e-cell-text.h>
+#include <table/e-cell-combo.h>
 #include <e-util/e-dialog-utils.h>
-#include <widgets/misc/e-cell-date-edit.h>
-#include <widgets/misc/e-cell-percent.h>
+#include <misc/e-cell-date-edit.h>
+#include <misc/e-cell-percent.h>
 
 #include "calendar-component.h"
 #include "calendar-config.h"
@@ -88,8 +88,6 @@ static gint e_calendar_table_on_key_press	(ETable		*table,
 static struct tm e_calendar_table_get_current_time (ECellDateEdit *ecde,
 						    gpointer data);
 static void mark_row_complete_cb (int model_row, gpointer data);
-static ECalModelComponent *get_selected_comp (ECalendarTable *cal_table);
-static void open_task (ECalendarTable *cal_table, ECalModelComponent *comp_data, gboolean assign);
 
 /* Signal IDs */
 enum {
@@ -594,7 +592,7 @@ e_calendar_table_open_selected (ECalendarTable *cal_table)
 	comp_data = get_selected_comp (cal_table);
 	prop = icalcomponent_get_first_property (comp_data->icalcomp, ICAL_ATTENDEE_PROPERTY);
 	if (comp_data != NULL)
-		open_task (cal_table, comp_data, prop ? TRUE : FALSE);
+		e_calendar_table_open_task (cal_table, comp_data, prop ? TRUE : FALSE);
 }
 
 /**
@@ -630,8 +628,8 @@ get_selected_row_cb (int model_row, gpointer data)
 /* Returns the component that is selected in the table; only works if there is
  * one and only one selected row.
  */
-static ECalModelComponent *
-get_selected_comp (ECalendarTable *cal_table)
+ECalModelComponent *
+e_calendar_table_get_selected_comp (ECalendarTable *cal_table)
 {
 	ETable *etable;
 	int row;
@@ -691,7 +689,7 @@ delete_selected_components (ECalendarTable *cal_table)
 
 	objs = get_selected_objects (cal_table);
 
-	e_calendar_table_set_status_message (cal_table, _("Deleting selected objects"));
+	e_calendar_table_set_status_message (cal_table, _("Deleting selected objects"), -1);
 
 	for (l = objs; l; l = l->next) {
 		ECalModelComponent *comp_data = (ECalModelComponent *) l->data;
@@ -703,7 +701,7 @@ delete_selected_components (ECalendarTable *cal_table)
 		g_clear_error (&error);
 	}
 
-	e_calendar_table_set_status_message (cal_table, NULL);
+	e_calendar_table_set_status_message (cal_table, NULL, -1);
 
 	g_slist_free (objs);
 }
@@ -732,7 +730,7 @@ e_calendar_table_delete_selected (ECalendarTable *cal_table)
 		return;
 
 	if (n_selected == 1)
-		comp_data = get_selected_comp (cal_table);
+		comp_data = e_calendar_table_get_selected_comp (cal_table);
 	else
 		comp_data = NULL;
 
@@ -870,7 +868,7 @@ clipboard_get_text_cb (GtkClipboard *clipboard, const gchar *text, ECalendarTabl
 
 	client = e_cal_model_get_default_client (cal_table->model);
 	
-	e_calendar_table_set_status_message (cal_table, _("Updating objects"));
+	e_calendar_table_set_status_message (cal_table, _("Updating objects"), -1);
 
 	if (kind == ICAL_VCALENDAR_COMPONENT) {
 		icalcomponent_kind child_kind;
@@ -916,7 +914,7 @@ clipboard_get_text_cb (GtkClipboard *clipboard, const gchar *text, ECalendarTabl
 		g_object_unref (comp);
 	}
 
-	e_calendar_table_set_status_message (cal_table, NULL);
+	e_calendar_table_set_status_message (cal_table, NULL, -1);
 }
 
 /**
@@ -935,8 +933,8 @@ e_calendar_table_paste_clipboard (ECalendarTable *cal_table)
 }
 
 /* Opens a task in the task editor */
-static void
-open_task (ECalendarTable *cal_table, ECalModelComponent *comp_data, gboolean assign)
+void
+e_calendar_table_open_task (ECalendarTable *cal_table, ECalModelComponent *comp_data, gboolean assign)
 {
 	CompEditor *tedit;
 	const char *uid;
@@ -970,7 +968,7 @@ open_task_by_row (ECalendarTable *cal_table, int row)
 
 	comp_data = e_cal_model_get_component_at (cal_table->model, row);
 	prop = icalcomponent_get_first_property (comp_data->icalcomp, ICAL_ATTENDEE_PROPERTY);
-	open_task (cal_table, comp_data, prop ? TRUE : FALSE);
+	e_calendar_table_open_task (cal_table, comp_data, prop ? TRUE : FALSE);
 }
 
 static void
@@ -992,10 +990,10 @@ e_calendar_table_on_open_task (EPopup *ep, EPopupItem *pitem, void *data)
 	ECalModelComponent *comp_data;
 	icalproperty *prop;
 
-	comp_data = get_selected_comp (cal_table);
+	comp_data = e_calendar_table_get_selected_comp (cal_table);
 	prop = icalcomponent_get_first_property (comp_data->icalcomp, ICAL_ATTENDEE_PROPERTY);
 	if (comp_data)
-		open_task (cal_table, comp_data, prop ? TRUE : FALSE);
+		e_calendar_table_open_task (cal_table, comp_data, prop ? TRUE : FALSE);
 }
 
 static void
@@ -1007,7 +1005,7 @@ e_calendar_table_on_save_as (EPopup *ep, EPopupItem *pitem, void *data)
 	char *ical_string;
 	FILE *file;
 
-	comp_data = get_selected_comp (cal_table);
+	comp_data = e_calendar_table_get_selected_comp (cal_table);
 	if (comp_data == NULL)
 		return;
 	
@@ -1039,7 +1037,7 @@ e_calendar_table_on_print_task (EPopup *ep, EPopupItem *pitem, void *data)
 	ECalModelComponent *comp_data;
 	ECalComponent *comp;
 
-	comp_data = get_selected_comp (cal_table);
+	comp_data = e_calendar_table_get_selected_comp (cal_table);
 	if (comp_data == NULL)
 		return;
 	
@@ -1080,9 +1078,9 @@ e_calendar_table_on_assign (EPopup *ep, EPopupItem *pitem, void *data)
 	ECalendarTable *cal_table = data;
 	ECalModelComponent *comp_data;
 
-	comp_data = get_selected_comp (cal_table);
+	comp_data = e_calendar_table_get_selected_comp (cal_table);
 	if (comp_data)
-		open_task (cal_table, comp_data, TRUE);
+		e_calendar_table_open_task (cal_table, comp_data, TRUE);
 }
 
 static void
@@ -1091,7 +1089,7 @@ e_calendar_table_on_forward (EPopup *ep, EPopupItem *pitem, void *data)
 	ECalendarTable *cal_table = data;
 	ECalModelComponent *comp_data;
 
-	comp_data = get_selected_comp (cal_table);
+	comp_data = e_calendar_table_get_selected_comp (cal_table);
 	if (comp_data) {
 		ECalComponent *comp;
 
@@ -1132,7 +1130,7 @@ open_url_cb (EPopup *ep, EPopupItem *pitem, void *data)
 	ECalModelComponent *comp_data;
 	icalproperty *prop;
 
-	comp_data = get_selected_comp (cal_table);
+	comp_data = e_calendar_table_get_selected_comp (cal_table);
 	if (!comp_data)
 		return;
 
@@ -1343,7 +1341,7 @@ e_calendar_table_set_activity_handler (ECalendarTable *cal_table, EActivityHandl
 }
 
 void
-e_calendar_table_set_status_message (ECalendarTable *cal_table, const gchar *message)
+e_calendar_table_set_status_message (ECalendarTable *cal_table, const gchar *message, int percent)
 {
         g_return_if_fail (E_IS_CALENDAR_TABLE (cal_table));
 
@@ -1366,6 +1364,15 @@ e_calendar_table_set_status_message (ECalendarTable *cal_table, const gchar *mes
 
                 g_free (client_id);
         } else {
-                e_activity_handler_operation_progressing (cal_table->activity_handler, cal_table->activity_id, message, -1.0);
+		
+		double progress;
+		
+		if (percent < 0)
+			progress = -1.0;
+		else {
+			progress = ((double) percent / 100);
+		}
+
+                e_activity_handler_operation_progressing (cal_table->activity_handler, cal_table->activity_id, message, progress);
 	}
 }
