@@ -54,6 +54,7 @@
 #include "e-cal-component-preview.h"
 #include "e-tasks.h"
 #include "common/authentication.h"
+#include "e-cal-menu.h"
 
 
 /* Private part of the GnomeCalendar structure */
@@ -74,6 +75,9 @@ struct _ETasksPrivate {
 	/* Calendar search bar for tasks */
 	GtkWidget *search_bar;
 
+	/* Tasks menu */
+	ECalMenu *tasks_menu;
+
 	/* Paned widget */
 	GtkWidget *paned;
 
@@ -97,6 +101,7 @@ static void update_view (ETasks *tasks);
 
 static void config_categories_changed_cb (EConfigListener *config_listener, const char *key, gpointer user_data);
 static void backend_error_cb (ECal *client, const char *message, gpointer data);
+ECalMenu *gnome_tasks_get_tasks_menu (ETasks *tasks);
 
 /* Signal IDs */
 enum {
@@ -161,6 +166,15 @@ table_cursor_change_cb (ETable *etable, int row, gpointer data)
 	g_object_unref (comp);
 }
 
+ECalMenu *
+gnome_tasks_get_tasks_menu (ETasks *tasks)
+{
+        g_return_val_if_fail (E_IS_TASKS (tasks), NULL);
+
+        return tasks->priv->tasks_menu;
+}
+
+
 /* Callback used when the selection changes in the table. */
 static void
 table_selection_change_cb (ETable *etable, gpointer data)
@@ -329,6 +343,21 @@ model_row_changed_cb (ETableModel *etm, int row, gpointer data)
 	}
 }
 
+static void
+view_progress_cb (ECalModel *model, const char *message, int percent, ECalSourceType type, ETasks *tasks)
+{
+	e_calendar_table_set_status_message (E_CALENDAR_TABLE (e_tasks_get_calendar_table (tasks)), 
+			message, percent);
+}
+
+static void
+view_done_cb (ECalModel *model, ECalendarStatus status, ECalSourceType type, ETasks *tasks)
+{
+	e_calendar_table_set_status_message (E_CALENDAR_TABLE (e_tasks_get_calendar_table (tasks)), 
+			NULL, -1);
+			
+}
+
 static void
 setup_config (ETasks *tasks)
 {
@@ -540,6 +569,11 @@ setup_widgets (ETasks *tasks)
 	model = e_calendar_table_get_model (E_CALENDAR_TABLE (priv->tasks_view));
 	g_signal_connect (G_OBJECT (model), "model_row_changed",
 			  G_CALLBACK (model_row_changed_cb), tasks);
+	
+	g_signal_connect (G_OBJECT (model), "cal_view_progress",
+				G_CALLBACK (view_progress_cb), tasks);
+	g_signal_connect (G_OBJECT (model), "cal_view_done",
+				G_CALLBACK (view_done_cb), tasks);
 }
 
 /* Class initialization function for the gnome calendar */
@@ -634,6 +668,7 @@ e_tasks_init (ETasks *tasks)
 	priv->current_uid = NULL;
 	priv->sexp = g_strdup ("#t");
 	priv->default_client = NULL;
+	priv->tasks_menu = e_cal_menu_new ("org.gnome.evolution.tasks.view");
 	update_view (tasks);
 }
 
@@ -744,7 +779,7 @@ set_status_message (ETasks *tasks, const char *message, ...)
 
 	priv = tasks->priv;
 	
-	e_calendar_table_set_status_message (E_CALENDAR_TABLE (priv->tasks_view), msg_string);
+	e_calendar_table_set_status_message (E_CALENDAR_TABLE (priv->tasks_view), msg_string, -1);
 }
 
 /* Callback from the calendar client when an error occurs in the backend */
@@ -784,7 +819,7 @@ backend_died_cb (ECal *client, gpointer data)
 
 	gtk_signal_emit (GTK_OBJECT (tasks), e_tasks_signals[SOURCE_REMOVED], source);
 
-	e_calendar_table_set_status_message (E_CALENDAR_TABLE (e_tasks_get_calendar_table (tasks)), NULL);
+	e_calendar_table_set_status_message (E_CALENDAR_TABLE (e_tasks_get_calendar_table (tasks)), NULL, -1);
 	
 	e_error_run (GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (tasks))),
 		     "calendar:tasks-crashed", NULL);
