@@ -31,7 +31,7 @@
 
 #include <e-util/e-account.h>
 #include <camel/camel-mime-message.h>
-#include <addressbook/util/e-destination.h>
+#include <libebook/e-destination.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -45,8 +45,6 @@ extern "C" {
 #define E_IS_MSG_COMPOSER_HDRS_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((obj), E_TYPE_MSG_COMPOSER_HDRS))
 
 
-#define SELECT_NAMES_OAFIID "OAFIID:GNOME_Evolution_Addressbook_SelectNames:" BASE_VERSION
-
 typedef struct _EMsgComposerHdrs        EMsgComposerHdrs;
 typedef struct _EMsgComposerHdrsClass   EMsgComposerHdrsClass;
 typedef struct _EMsgComposerHdrsPrivate EMsgComposerHdrsPrivate;
