@@ -620,7 +620,11 @@ add_addressbook_sources (EAccount *account)
 		e_source_set_property (source, "auth-domain", "Groupwise");
 		e_source_set_property (source, "port", soap_port);
 		e_source_set_property(source, "user", url->user);
-		e_source_set_property (source, "offline_sync", camel_url_get_param (url, "offline_sync") ? "1" : "0");
+		if (!strcmp (book_name, "Novell GroupWise Address Book"))
+			e_source_set_property (source, "offline_sync", "1");
+		else
+			e_source_set_property (source, "offline_sync", 
+					       camel_url_get_param (url, "offline_sync") ? "1" : "0");
 		if (!e_gw_container_get_is_writable (E_GW_CONTAINER(temp_list->data)))
 			e_source_set_property (source, "completion", "true");
 		if (e_gw_container_get_is_frequent_contacts (E_GW_CONTAINER(temp_list->data)))
