@@ -670,6 +670,7 @@ setup_widgets (EShellWindow *window)
 		
 		e_sidebar_set_mode (E_SIDEBAR (priv->sidebar), mode);
 	}
+	g_free (style);
 
 	/* The tool bar */
 	visible = gconf_client_get_bool (gconf_client,
@@ -694,6 +695,9 @@ setup_widgets (EShellWindow *window)
 		ComponentView *view = component_view_new (info->id, info->alias, button_id);
 
 		window->priv->component_views = g_slist_prepend (window->priv->component_views, view);
+
+		if (!info->button_label || !info->menu_label)
+			continue;
 		e_sidebar_add_button (E_SIDEBAR (priv->sidebar), info->button_label, info->button_tooltips, info->button_icon, button_id);
 
 		g_string_printf(xml, "SwitchComponent-%s", info->alias);
@@ -702,7 +706,8 @@ setup_widgets (EShellWindow *window)
 					      (BonoboUIVerbFn)menu_component_selected,
 					      window);
 
-		g_string_printf(xml, "<submenu name=\"Tools\">"
+		g_string_printf(xml, "<submenu name=\"View\">"
+				"<submenu name=\"Window\">"
 				"<placeholder name=\"WindowComponent\">"
 				"<menuitem name=\"SwitchComponent-%s\" "
 				"verb=\"\" label=\"%s\" accel=\"%s\" tip=\"",
@@ -712,7 +717,7 @@ setup_widgets (EShellWindow *window)
 		g_string_append_printf(xml, _("Switch to %s"), info->button_label);
 		tmp = bonobo_ui_util_pixbuf_to_xml (info->menu_icon),
 		g_string_append_printf(xml, "\" pixtype=\"pixbuf\" pixname=\"%s\"/>"
-				       "</placeholder></submenu>\n",
+				       "</placeholder></submenu></submenu>\n",
 				       tmp);
 		g_free(tmp);
 		bonobo_ui_component_set_translate (e_shell_window_peek_bonobo_ui_component (window),
